# Pelp

CLI for Programming Language Documentation

### Installing

```
pip install pelp
``` 

## Usage

```
Python

pelp python (string/list/dict/set/all) 
```

```
Javascript

pelp javascript (string/array/map/all)
```

## Note from me

Thank you for taking the time to look at this. 
If you see anything that you would like to change/add
please don't hesitate to do so. I would really like Pelp 
to be the one stop shop for all of our documentation needs
